@@ -1,4 +1,7 @@
-from serverless.aws.iam import IAMPreset
+import re
+
+from serverless.aws.iam import IAMPreset, PolicyBuilder
+from serverless.service import Identifier
 
 
 class Execute(IAMPreset):
@@ -6,17 +9,14 @@ class Execute(IAMPreset):
         self.api = api
         self.endpoint = endpoint
 
-    def apply(self, service, sid=None):
-        if not sid:
-            sid = f"Invoke"
-
+    def apply(self, policy_builder: PolicyBuilder, sid=None):
         if not str(self.endpoint).startswith("arn:aws:execute-api:"):
             arn = "arn:aws:execute-api:${aws:region}:${aws:accountId}:" + self.api + "/${sls:stage}/" + self.endpoint
         else:
             arn = self.endpoint
 
-        service.provider.iam.allow(
-            sid,
-            ["execute-api:Invoke"],
-            [arn],
+        policy_builder.allow(
+            permissions=["execute-api:Invoke"],
+            resources=[arn],
+            sid=sid or "Invoke" + Identifier(re.sub(r"\W", "", self.endpoint)).pascal,
         )
